| /llvm-project-15.0.7/lld/test/ELF/ |
| H A D | amdgpu-kernels.s | 18 .globl kernel1 20 .amdgpu_hsa_kernel kernel1 21 kernel1: label 25 .size kernel1, .Lfunc_end1-kernel1 50 # CHECK: Name: kernel1
|
| /llvm-project-15.0.7/llvm/test/Transforms/OpenMP/ |
| H A D | gpu_kernel_detection_remarks.ll | 4 ; CHECK-DAG: remark: <unknown>:0:0: OpenMP GPU kernel kernel1 7 define void @kernel1() { 25 !0 = !{void ()* @kernel1, !"kernel", i32 1}
|
| H A D | get_hardware_num_threads_in_block_fold_optnone.ll | 36 define weak void @kernel1() #0 { 37 ; CHECK-LABEL: define {{[^@]+}}@kernel1 127 !3 = !{void ()* @kernel1, !"kernel", i32 1} 137 ; CHECK: [[META3:![0-9]+]] = !{void ()* @kernel1, !"kernel", i32 1}
|
| H A D | get_hardware_num_threads_in_block_fold.ll | 38 define weak void @kernel1() #0 { 39 ; CHECK-LABEL: define {{[^@]+}}@kernel1 205 !3 = !{void ()* @kernel1, !"kernel", i32 1} 217 ; CHECK: [[META3:![0-9]+]] = !{void ()* @kernel1, !"kernel", i32 1}
|
| /llvm-project-15.0.7/clang/test/SemaCUDA/ |
| H A D | call-kernel-from-kernel.cu | 6 __global__ void kernel1(); 8 …kernel1<<<1,1>>>(); // expected-error {{reference to __global__ function 'kernel1' in __global__ f… in kernel2()
|
| /llvm-project-15.0.7/clang/test/CodeGenOpenCL/ |
| H A D | norecurse.cl | 3 kernel void kernel1(int a) {} 4 // CHECK: define{{.*}}@kernel1{{.*}}#[[ATTR:[0-9]*]]
|
| H A D | kernel-attributes.cl | 5 …tribute__((vec_type_hint(int))) __attribute__((reqd_work_group_size(1,2,4))) void kernel1(int a) {} 6 // CHECK: define {{(dso_local )?}}spir_kernel void @kernel1(i32 {{[^%]*}}%a) {{[^{]+}} !vec_type_hi…
|
| /llvm-project-15.0.7/clang/test/CodeGenCUDA/ |
| H A D | host-used-extern.cu | 28 __global__ void kernel1(); 48 kernel1<<<1, 1>>>(); in test()
|
| H A D | norecurse.cu | 12 __global__ void kernel1(int a) {} in kernel1() function
|
| H A D | debug-info-address-class.cu | 15 __device__ void kernel1( in kernel1() function
|
| /llvm-project-15.0.7/llvm/test/DebugInfo/AMDGPU/ |
| H A D | dbg-value-sched-crash.ll | 10 ; kernel void kernel1(global int *A, global int *B) { 21 ; CHECK-LABEL: {{^}}kernel1: 22 define amdgpu_kernel void @kernel1( 62 !7 = distinct !DISubprogram(name: "kernel1", scope: !1, file: !1, line: 1, type: !8, isLocal: false…
|
| H A D | dwarfdump-relocs.ll | 7 ; kernel void kernel1(global int addrspace(5)*A) { 22 define amdgpu_kernel void @kernel1(i32 addrspace(1)* %A) !dbg !7 { 54 !7 = distinct !DISubprogram(name: "kernel1", scope: !1, file: !1, line: 1, type: !8, isLocal: false…
|
| H A D | code-pointer-size.ll | 7 ; kernel void kernel1(global int addrspace(5)*A) { 21 define amdgpu_kernel void @kernel1(i32 addrspace(1)* %A) !dbg !7 { 53 !7 = distinct !DISubprogram(name: "kernel1", scope: !1, file: !1, line: 1, type: !8, isLocal: false…
|
| H A D | pointer-address-space.ll | 7 ; kernel void kernel1() { 54 define amdgpu_kernel void @kernel1() !dbg !7 { 86 !7 = distinct !DISubprogram(name: "kernel1", scope: !1, file: !1, line: 1, type: !8, isLocal: false…
|
| H A D | variable-locations.ll | 10 ; kernel void kernel1(unsigned int ArgN, global int addrspace(5)*ArgA, global int addrspace(5)*Ar… 37 define amdgpu_kernel void @kernel1( 93 !13 = distinct !DISubprogram(name: "kernel1", scope: !3, file: !3, line: 4, type: !14, isLocal: fal…
|
| /llvm-project-15.0.7/llvm/test/CodeGen/AMDGPU/ |
| H A D | propagate-attributes-bitcast-function.ll | 6 ; GCN: kernel1: 17 define amdgpu_kernel void @kernel1(float %x) #0 {
|
| H A D | propagate-attributes-single-set.ll | 10 ; OPT: define amdgpu_kernel void @kernel1() local_unnamed_addr #2 30 ; LLC: kernel1: 61 define amdgpu_kernel void @kernel1() #0 {
|
| H A D | call-alias-register-usage1.ll | 11 ; CHECK-LABEL: {{^}}kernel1: 14 define amdgpu_kernel void @kernel1() #0 {
|
| H A D | uniform-work-group-propagate-attribute.ll | 20 define amdgpu_kernel void @kernel1() #1 { 21 ; CHECK-LABEL: define {{[^@]+}}@kernel1
|
| H A D | uniform-work-group-attribute-missing.ll | 22 define amdgpu_kernel void @kernel1() #1 { 23 ; CHECK-LABEL: define {{[^@]+}}@kernel1
|
| H A D | nop-data.ll | 82 ; CHECK-NEXT: <kernel1>: 84 define amdgpu_kernel void @kernel1(i32 addrspace(1)* addrspace(4)* %ptr.out) align 256 {
|
| H A D | uniform-work-group-prevent-attribute-propagation.ll | 22 define amdgpu_kernel void @kernel1() #1 { 23 ; CHECK-LABEL: define {{[^@]+}}@kernel1
|
| /llvm-project-15.0.7/mlir/test/Integration/Dialect/Vector/CPU/AMX/ |
| H A D | test-muli-ext.mlir | 20 func.func @kernel1(%arg0: memref<16x16xi8>, 103 // Call kernel1 and verify result. 122 call @kernel1(%a, %b, %c) : (memref<16x16xi8>, memref<4x16xi8>, memref<16x4xi32>) -> ()
|
| H A D | test-mulf.mlir | 9 func.func @kernel1(%arg0: memref<2x4xbf16>, 53 call @kernel1(%a, %b, %c) : (memref<2x4xbf16>, memref<2x4xbf16>, memref<2x2xf32>) -> ()
|
| H A D | test-muli.mlir | 9 func.func @kernel1(%arg0: memref<2x8xi8>, 53 call @kernel1(%a, %b, %c) : (memref<2x8xi8>, memref<2x8xi8>, memref<2x2xi32>) -> ()
|